==> haskell-binary-tagged-0.3.1-181-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-tagged
version:              0.3.1
visibility:           public
id:                   binary-tagged-0.3.1-GYrCmVX8ame9fapD2ILzCT
key:                  binary-tagged-0.3.1-GYrCmVX8ame9fapD2ILzCT
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Tagged binary serialisation.
description:
    Structurally tag binary serialisation stream.

    Say you have:

    Say you have a data type

    @
    data Record = Record
    \  { _recordFields  :: HM.HashMap Text (Integer, ByteString)
    \  , _recordEnabled :: Bool
    \  }
    \  deriving (Eq, Show, Generic)

    instance @Binary@ Record
    instance '\''Structured'\'' Record
    @

    then you can serialise and deserialise @Record@ values with a structure tag by simply

    @
    '\''structuredEncode'\'' record :: LBS.ByteString
    '\''structuredDecode'\'' lbs    :: IO Record
    @

    If structure of @Record@ changes in between, deserialisation will fail early.

    The overhead is next to non-observable.

    @
    benchmarking encode/Binary
    time                 352.8 μs   (349.5 μs .. 355.9 μs)

    benchmarking encode/Tagged
    time                 350.8 μs   (349.0 μs .. 353.1 μs)

    benchmarking decode/Binary
    time                 346.8 μs   (344.7 μs .. 349.9 μs)

    benchmarking decode/Tagged
    time                 353.8 μs   (352.0 μs .. 355.8 μs)
    @

category:             Data
abi:                  9a81467e3f0da7b61b50ecc5bba99214
exposed:              True
exposed-modules:      Data.Binary.Tagged
import-dirs:          /usr/lib/ghc-9.2.8/site-local/binary-tagged-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/binary-tagged-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-tagged
hs-libraries:         HSbinary-tagged-0.3.1-GYrCmVX8ame9fapD2ILzCT
depends:
    array-0.5.4.0 base-4.16.4.0
    base16-bytestring-1.0.2.0-9AKEfJpeJHOK2mzYhoV7G4 binary-0.8.9.0
    bytestring-0.11.4.0 containers-0.6.5.1
    structured-0.1.1-JeqTMil3PXPLQtzzpX0UMl
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg

haddock-interfaces:
    /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock

haddock-html:         /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-tagged-0.3.1-190-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-tagged
version:              0.3.1
visibility:           public
id:                   binary-tagged-0.3.1-KJyuzEIbhjsJOYYdJKxMW6
key:                  binary-tagged-0.3.1-KJyuzEIbhjsJOYYdJKxMW6
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Tagged binary serialisation.
description:
    Structurally tag binary serialisation stream.

    Say you have:

    Say you have a data type

    @
    data Record = Record
    \  { _recordFields  :: HM.HashMap Text (Integer, ByteString)
    \  , _recordEnabled :: Bool
    \  }
    \  deriving (Eq, Show, Generic)

    instance @Binary@ Record
    instance '\''Structured'\'' Record
    @

    then you can serialise and deserialise @Record@ values with a structure tag by simply

    @
    '\''structuredEncode'\'' record :: LBS.ByteString
    '\''structuredDecode'\'' lbs    :: IO Record
    @

    If structure of @Record@ changes in between, deserialisation will fail early.

    The overhead is next to non-observable.

    @
    benchmarking encode/Binary
    time                 352.8 μs   (349.5 μs .. 355.9 μs)

    benchmarking encode/Tagged
    time                 350.8 μs   (349.0 μs .. 353.1 μs)

    benchmarking decode/Binary
    time                 346.8 μs   (344.7 μs .. 349.9 μs)

    benchmarking decode/Tagged
    time                 353.8 μs   (352.0 μs .. 355.8 μs)
    @

category:             Data
abi:                  aa8179c3f5e29ee97e58b10c7a9eacdd
exposed:              True
exposed-modules:      Data.Binary.Tagged
import-dirs:          /usr/lib/ghc-9.2.8/site-local/binary-tagged-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/binary-tagged-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-tagged
hs-libraries:         HSbinary-tagged-0.3.1-KJyuzEIbhjsJOYYdJKxMW6
depends:
    array-0.5.4.0 base-4.16.4.0
    base16-bytestring-1.0.2.0-1EKQKfIbtqrKykCu8OdSyV binary-0.8.9.0
    bytestring-0.11.4.0 containers-0.6.5.1
    structured-0.1.1-DTGcFHTqLB3D218ZoAoPZl
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg

haddock-interfaces:
    /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock

haddock-html:         /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
